@@ -1,2 +1,2 @@
-from globalplatform.encodings import SecureMessaging, CLA
+from globalplatform.encodings import CardPersonalizationLifeCycleData, SecureMessaging, CLA, CPLC
 from globalplatform.commands import GetDataObject, FileOccurrence, ApplicationIdentifier, GET_DATA, SELECT
